@@ -162,7 +162,8 @@ class ApiList(View):
                 rows = []
                 for obj in ar.sliced_data_iterator:
                     url = ar.renderer.obj2url(ar, obj)
-                    # url = url.replace('"', r'\"')
+                    import html
+                    url = html.escape(url)
                     html_text += """<a href="{}"><p>{}</p></a>""".format(
                         url, ar.row_as_paragraph(obj))
                     rows.append({'id': obj.pk})
@@ -291,7 +292,10 @@ class DelayedValue(View):
                 row = ar.selected_rows[0]
                 # raise NotImplementedError()
             sf = get_atomizer(rpt, de, field)
-            v = sf.full_value_from_object(row, ar)
+            if sf is None:
+                v = "Oops, get_atomizer({}, {}, {}) returned None".format(rpt, de, field)
+            else:
+                v = sf.full_value_from_object(row, ar)
             # v = de._lino_atomizer.full_value_from_object(row, ar)
         # print("20210619b", de, v)
         return json_response({'data': v})
@@ -583,7 +587,7 @@ class Authenticate(View):
 
         # target = '/user/settings/'
         def result():
-            if not settings.SITE.build_js_cache_on_startup:
+            if settings.SITE.developer_site_cache:
                 settings.SITE.plugins.react.renderer.build_js_cache(False)
             # http.HttpResponseRedirect(target) # Seems that fetch has some issues with this...
             return json_response({"success": True})
@@ -635,6 +639,10 @@ class Index(View):
                 user=user,  # Current user
             )
             context.update(ar=ar)
+
+            if 'update_found' in request.GET:
+                context.update(lv=f"?lv={int(settings.SITE.kernel.code_mtime)}")
+
             context = ar.get_printable_context(**context)
             env = settings.SITE.plugins.jinja.renderer.jinja_env
             template = env.get_template("react/main.html")
@@ -665,7 +673,7 @@ class UserSettings(View):
 
         def getit():
             # print(20200419, settings.SITE.build_media_url(*settings.SITE.plugins.react.renderer.lino_js_parts()))
-            if (not settings.SITE.build_js_cache_on_startup
+            if (settings.SITE.developer_site_cache
                 and not settings.SITE.never_build_site_cache):
                 settings.SITE.plugins.react.renderer.build_js_cache(False)
 
